﻿using System.ComponentModel;
using System.Linq;
using Abt.Controls.SciChart;
using Abt.Controls.SciChart.Model.DataSeries;
using Abt.Controls.SciChart.Visuals.Axes;

namespace ScreenshotsAndXpsExport
{
    public class ChartViewModel : INotifyPropertyChanged
    {
        public event PropertyChangedEventHandler PropertyChanged;

        private IDataSeries<int, double> _dataSeries;
        private ILabelProvider _labelFormatter;

        public ChartViewModel()
        {
            _dataSeries = new XyDataSeries<int, double>();

            // Create the X-Axis Labels
            var xAxisLabels = new[] {"Java", "Obj-C", "C#", "Fortran", "C++"};

            // We append Y-values (double) and X-values are just indices to the x-axis (string) labels
            _dataSeries.Append(Enumerable.Range(0, 5), new[] { 2.2, 5.3, 9.5, 6.7, 8.4});

            // The ILabelFormatter allows us to substitute a string value for a data-value. 
            // In most cases this is used to format a numeric value, e.g. 1.23456 as "1.23", however
            // we can also use it to transform an integer value to a string (text) value
            XLabelFormatter = new CustomLabelFormatter(xAxisLabels);
        }

        public IDataSeries<int, double> DataSeries
        {
            get { return _dataSeries; }
            set
            {
                _dataSeries = value;
                OnPropertyChanged("DataSeries");
            }
        }

        public ILabelProvider XLabelFormatter
        {
            get { return _labelFormatter; }
            set
            {
                _labelFormatter = value;
                OnPropertyChanged("XLabelFormatter");
            }
        }

        protected virtual void OnPropertyChanged(string propertyName = null)
        {
            PropertyChangedEventHandler handler = PropertyChanged;
            if (handler != null) handler(this, new PropertyChangedEventArgs(propertyName));
        }
    }
}
