﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Abt.Controls.SciChart;
using Abt.Controls.SciChart.Visuals.Axes;

namespace ScreenshotsAndXpsExport
{
    public class CustomLabelFormatter : LabelProviderBase
    {
        private readonly string[] _xLabels;

        public CustomLabelFormatter(string[] xLabels)
        {
            _xLabels = xLabels;
        }

        /// <summary>
        /// Called when the label formatted is initialized as it is attached to the parent axis, with the parent axis instance
        /// </summary>
        /// <param name="parentAxis">The parent <see cref="IAxis" /> instance</param>
        public override void Init(IAxis parentAxis)
        {
        }

        /// <summary>
        /// Called at the start of an axis render pass, before any labels are formatted for the current draw operation
        /// </summary>
        public override void OnBeginAxisDraw()
        {
        }

        /// <summary>
        /// Formats a label for the axis from the specified data-value passed in
        /// </summary>
        /// <param name="dataValue">The data-value to format</param>
        /// <returns>
        /// The formatted label string
        /// </returns>
        /// <exception cref="System.NotImplementedException"></exception>
        public override string FormatLabel(IComparable dataValue)
        {
            int index = (int) Convert.ChangeType(dataValue, typeof (int));
            if (index >= 0 && index < _xLabels.Length)
                return _xLabels[index];

            return index.ToString();
        }

        /// <summary>
        /// Formats a label for the cursor, from the specified data-value passed in
        /// </summary>
        /// <param name="dataValue">The data-value to format</param>
        /// <returns>
        /// The formatted cursor label string
        /// </returns>
        /// <exception cref="System.NotImplementedException"></exception>
        public override string FormatCursorLabel(IComparable dataValue)
        {
            int index = (int)Convert.ChangeType(dataValue, typeof(int));
            if (index >= 0 && index < _xLabels.Length)
                return _xLabels[index];

            return index.ToString();
        }
    }
}
