﻿using System;
using System.Diagnostics;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Input;
using System.Windows.Media;
using Abt.Controls.SciChart;
using Abt.Controls.SciChart.Visuals;
using Microsoft.Win32;

namespace ScreenshotsAndXpsExport
{
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
        }

        private void CopyToClipboardClick(object sender, RoutedEventArgs e)
        {
            // See SciChartSurfaceExtensions where ExportBitmapToClipboard is defined
            var bmp = customUserControl.SciChartSurface.ExportToBitmapSource();
            Clipboard.SetImage(bmp);

            MessageBox.Show("Copied to Clipboard!");
        }

        private void SaveAsPngClick(object sender, RoutedEventArgs e)
        {
            var dialog = new SaveFileDialog();
            dialog.DefaultExt = "png";
            dialog.AddExtension = true;
            dialog.Filter = "Png Files|*.png";
            dialog.InitialDirectory = Environment.GetFolderPath(Environment.SpecialFolder.Desktop);
            if (dialog.ShowDialog() == true)
            {
                customUserControl.SciChartSurface.ExportToFile(dialog.FileName, ExportType.Png);
                Process.Start(dialog.FileName);
            }
        }

        private void PrintToXpsClick(object sender, RoutedEventArgs e)
        {
            var dialog = new PrintDialog();
            if (dialog.ShowDialog() == true)
            {
                var size = new Size(dialog.PrintableAreaWidth, dialog.PrintableAreaWidth*3/4);

                var scs = CreateSciChartSurfaceWithoutShowingIt(size);

                // And print. This works particularly well to XPS! 
                Action printAction = () => dialog.PrintVisual(scs, "Programmer Awesomeness");
                Dispatcher.BeginInvoke(printAction);
            }
        }

        /// <summary>
        /// This method demonstrates how we can render to bitmap or print a SciChartSurface which is never shown, 
        /// e.g. if you wanted to create a report on a server, or wanted to grab a screenshot at a different resolution
        /// to the currently shown size of the chart
        /// </summary>
        /// <param name="size"></param>
        /// <returns></returns>
        private Visual CreateSciChartSurfaceWithoutShowingIt(Size size)
        {
            // Create a fresh ChartView, this contains the ViewModel (declared in XAML) and data
            var control = new ChartView();
            var scs = control.SciChartSurface;

            // We must set a width and height. If you are rendering off screen without showing 
            // we have to tell the control what size to render
            scs.Width = size.Width;
            scs.Height = size.Height;

            // Doing an export sets up the chart for rendering off screen, including handling all the horrible layout issues
            // that occur when a WPF element is created and rendered without showing it. 
            // 
            // You must call this before printing, even if you don't intend to use the bitmap. 
            scs.ExportToBitmapSource();

            return scs;
        }

        private void CustomUserControl_OnMouseDoubleClick(object sender, MouseButtonEventArgs e)
        {
            // See SciChartSurfaceExtensions where ExportBitmapToClipboard is defined
            var bmp = customUserControl.SciChartSurface.ExportToBitmapSource();
            Clipboard.SetImage(bmp);

            MessageBox.Show("Copied to Clipboard!");
        }
    }
}
